==> openshift-model-operator-7.1.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeDisruptionPolicySpecSSHKeyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NodeDisruptionPolicySpecSSHKeyFluent<A extends NodeDisruptionPolicySpecSSHKeyFluent<A>> extends BaseFluent<A>{
  public NodeDisruptionPolicySpecSSHKeyFluent() {
  }
  
  public NodeDisruptionPolicySpecSSHKeyFluent(NodeDisruptionPolicySpecSSHKey instance) {
    this.copyInstance(instance);
  }
  private ArrayList<NodeDisruptionPolicySpecActionBuilder> actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NodeDisruptionPolicySpecSSHKey instance) {
    instance = (instance != null ? instance : new NodeDisruptionPolicySpecSSHKey());
    if (instance != null) {
          this.withActions(instance.getActions());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToActions(int index,NodeDisruptionPolicySpecAction item) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);
    if (index < 0 || index >= actions.size()) { _visitables.get("actions").add(builder); actions.add(builder); } else { _visitables.get("actions").add(index, builder); actions.add(index, builder);}
    return (A)this;
  }
  
  public A setToActions(int index,NodeDisruptionPolicySpecAction item) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);
    if (index < 0 || index >= actions.size()) { _visitables.get("actions").add(builder); actions.add(builder); } else { _visitables.get("actions").set(index, builder); actions.set(index, builder);}
    return (A)this;
  }
  
  public A addToActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... items) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  
  public A addAllToActions(Collection<NodeDisruptionPolicySpecAction> items) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  
  public A removeFromActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... items) {
    if (this.actions == null) return (A)this;
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").remove(builder); this.actions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromActions(Collection<NodeDisruptionPolicySpecAction> items) {
    if (this.actions == null) return (A)this;
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").remove(builder); this.actions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromActions(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
    if (actions == null) return (A) this;
    final Iterator<NodeDisruptionPolicySpecActionBuilder> each = actions.iterator();
    final List visitables = _visitables.get("actions");
    while (each.hasNext()) {
      NodeDisruptionPolicySpecActionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<NodeDisruptionPolicySpecAction> buildActions() {
    return this.actions != null ? build(actions) : null;
  }
  
  public NodeDisruptionPolicySpecAction buildAction(int index) {
    return this.actions.get(index).build();
  }
  
  public NodeDisruptionPolicySpecAction buildFirstAction() {
    return this.actions.get(0).build();
  }
  
  public NodeDisruptionPolicySpecAction buildLastAction() {
    return this.actions.get(actions.size() - 1).build();
  }
  
  public NodeDisruptionPolicySpecAction buildMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
      for (NodeDisruptionPolicySpecActionBuilder item : actions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
      for (NodeDisruptionPolicySpecActionBuilder item : actions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withActions(List<NodeDisruptionPolicySpecAction> actions) {
    if (this.actions != null) {
      this._visitables.get("actions").clear();
    }
    if (actions != null) {
        this.actions = new ArrayList();
        for (NodeDisruptionPolicySpecAction item : actions) {
          this.addToActions(item);
        }
    } else {
      this.actions = null;
    }
    return (A) this;
  }
  
  public A withActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... actions) {
    if (this.actions != null) {
        this.actions.clear();
        _visitables.remove("actions");
    }
    if (actions != null) {
      for (NodeDisruptionPolicySpecAction item : actions) {
        this.addToActions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasActions() {
    return this.actions != null && !this.actions.isEmpty();
  }
  
  public ActionsNested<A> addNewAction() {
    return new ActionsNested(-1, null);
  }
  
  public ActionsNested<A> addNewActionLike(NodeDisruptionPolicySpecAction item) {
    return new ActionsNested(-1, item);
  }
  
  public ActionsNested<A> setNewActionLike(int index,NodeDisruptionPolicySpecAction item) {
    return new ActionsNested(index, item);
  }
  
  public ActionsNested<A> editAction(int index) {
    if (actions.size() <= index) throw new RuntimeException("Can't edit actions. Index exceeds size.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public ActionsNested<A> editFirstAction() {
    if (actions.size() == 0) throw new RuntimeException("Can't edit first actions. The list is empty.");
    return setNewActionLike(0, buildAction(0));
  }
  
  public ActionsNested<A> editLastAction() {
    int index = actions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last actions. The list is empty.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public ActionsNested<A> editMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<actions.size();i++) { 
    if (predicate.test(actions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching actions. No match found.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeDisruptionPolicySpecSSHKeyFluent that = (NodeDisruptionPolicySpecSSHKeyFluent) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(actions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null && !actions.isEmpty()) { sb.append("actions:"); sb.append(actions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ActionsNested<N> extends NodeDisruptionPolicySpecActionFluent<ActionsNested<N>> implements Nested<N>{
    ActionsNested(int index,NodeDisruptionPolicySpecAction item) {
      this.index = index;
      this.builder = new NodeDisruptionPolicySpecActionBuilder(this, item);
    }
    NodeDisruptionPolicySpecActionBuilder builder;
    int index;
    
    public N and() {
      return (N) NodeDisruptionPolicySpecSSHKeyFluent.this.setToActions(index,builder.build());
    }
    
    public N endAction() {
      return and();
    }
    
  
  }

}

==> openshift-model-operator-7.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeDisruptionPolicySpecSSHKeyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NodeDisruptionPolicySpecSSHKeyFluent<A extends NodeDisruptionPolicySpecSSHKeyFluent<A>> extends BaseFluent<A>{
  public NodeDisruptionPolicySpecSSHKeyFluent() {
  }
  
  public NodeDisruptionPolicySpecSSHKeyFluent(NodeDisruptionPolicySpecSSHKey instance) {
    this.copyInstance(instance);
  }
  private ArrayList<NodeDisruptionPolicySpecActionBuilder> actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NodeDisruptionPolicySpecSSHKey instance) {
    instance = (instance != null ? instance : new NodeDisruptionPolicySpecSSHKey());
    if (instance != null) {
          this.withActions(instance.getActions());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToActions(int index,NodeDisruptionPolicySpecAction item) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);
    if (index < 0 || index >= actions.size()) {
        _visitables.get("actions").add(builder);
        actions.add(builder);
    } else {
        _visitables.get("actions").add(builder);
        actions.add(index, builder);
    }
    return (A)this;
  }
  
  public A setToActions(int index,NodeDisruptionPolicySpecAction item) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);
    if (index < 0 || index >= actions.size()) {
        _visitables.get("actions").add(builder);
        actions.add(builder);
    } else {
        _visitables.get("actions").add(builder);
        actions.set(index, builder);
    }
    return (A)this;
  }
  
  public A addToActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... items) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  
  public A addAllToActions(Collection<NodeDisruptionPolicySpecAction> items) {
    if (this.actions == null) {this.actions = new ArrayList<NodeDisruptionPolicySpecActionBuilder>();}
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  
  public A removeFromActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... items) {
    if (this.actions == null) return (A)this;
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").remove(builder); this.actions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromActions(Collection<NodeDisruptionPolicySpecAction> items) {
    if (this.actions == null) return (A)this;
    for (NodeDisruptionPolicySpecAction item : items) {NodeDisruptionPolicySpecActionBuilder builder = new NodeDisruptionPolicySpecActionBuilder(item);_visitables.get("actions").remove(builder); this.actions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromActions(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
    if (actions == null) return (A) this;
    final Iterator<NodeDisruptionPolicySpecActionBuilder> each = actions.iterator();
    final List visitables = _visitables.get("actions");
    while (each.hasNext()) {
      NodeDisruptionPolicySpecActionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<NodeDisruptionPolicySpecAction> buildActions() {
    return this.actions != null ? build(actions) : null;
  }
  
  public NodeDisruptionPolicySpecAction buildAction(int index) {
    return this.actions.get(index).build();
  }
  
  public NodeDisruptionPolicySpecAction buildFirstAction() {
    return this.actions.get(0).build();
  }
  
  public NodeDisruptionPolicySpecAction buildLastAction() {
    return this.actions.get(actions.size() - 1).build();
  }
  
  public NodeDisruptionPolicySpecAction buildMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
      for (NodeDisruptionPolicySpecActionBuilder item : actions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
      for (NodeDisruptionPolicySpecActionBuilder item : actions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withActions(List<NodeDisruptionPolicySpecAction> actions) {
    if (this.actions != null) {
      this._visitables.get("actions").clear();
    }
    if (actions != null) {
        this.actions = new ArrayList();
        for (NodeDisruptionPolicySpecAction item : actions) {
          this.addToActions(item);
        }
    } else {
      this.actions = null;
    }
    return (A) this;
  }
  
  public A withActions(io.fabric8.openshift.api.model.operator.v1.NodeDisruptionPolicySpecAction... actions) {
    if (this.actions != null) {
        this.actions.clear();
        _visitables.remove("actions");
    }
    if (actions != null) {
      for (NodeDisruptionPolicySpecAction item : actions) {
        this.addToActions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasActions() {
    return this.actions != null && !this.actions.isEmpty();
  }
  
  public ActionsNested<A> addNewAction() {
    return new ActionsNested(-1, null);
  }
  
  public ActionsNested<A> addNewActionLike(NodeDisruptionPolicySpecAction item) {
    return new ActionsNested(-1, item);
  }
  
  public ActionsNested<A> setNewActionLike(int index,NodeDisruptionPolicySpecAction item) {
    return new ActionsNested(index, item);
  }
  
  public ActionsNested<A> editAction(int index) {
    if (actions.size() <= index) throw new RuntimeException("Can't edit actions. Index exceeds size.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public ActionsNested<A> editFirstAction() {
    if (actions.size() == 0) throw new RuntimeException("Can't edit first actions. The list is empty.");
    return setNewActionLike(0, buildAction(0));
  }
  
  public ActionsNested<A> editLastAction() {
    int index = actions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last actions. The list is empty.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public ActionsNested<A> editMatchingAction(Predicate<NodeDisruptionPolicySpecActionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<actions.size();i++) { 
    if (predicate.test(actions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching actions. No match found.");
    return setNewActionLike(index, buildAction(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeDisruptionPolicySpecSSHKeyFluent that = (NodeDisruptionPolicySpecSSHKeyFluent) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(actions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null && !actions.isEmpty()) { sb.append("actions:"); sb.append(actions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ActionsNested<N> extends NodeDisruptionPolicySpecActionFluent<ActionsNested<N>> implements Nested<N>{
    ActionsNested(int index,NodeDisruptionPolicySpecAction item) {
      this.index = index;
      this.builder = new NodeDisruptionPolicySpecActionBuilder(this, item);
    }
    NodeDisruptionPolicySpecActionBuilder builder;
    int index;
    
    public N and() {
      return (N) NodeDisruptionPolicySpecSSHKeyFluent.this.setToActions(index,builder.build());
    }
    
    public N endAction() {
      return and();
    }
    
  
  }

}
